@@ -10,7 +10,7 @@ else
 	T=-Tascii
 fi
 opts=
-safe=-S
+safer=-S
 
 for i
 do
@@ -36,12 +36,12 @@ do
 		# ignore other devices
 		;;
 	-S)
-		# safe behaviour
-		safe=-S
+		# safer behaviour
+		safer=-S
 		;;
 	-U)
 		# unsafe behaviour
-		safe=-U
+		safer=-U
 		;;
 	-u*)
 		# Solaris 2.2 `man' uses -u0; ignore it,
@@ -67,4 +67,4 @@ done
 
 # This shell script is intended for use with man, so warnings are
 # probably not wanted.  Also load nroff-style character definitions.
-exec groff $safe -Wall -mtty-char $T $opts ${1+"$@"}
+exec groff $safer -Wall -mtty-char $T $opts ${1+"$@"}
